@@ -33,8 +33,6 @@
 
 #include <AkonadiCore/ServerManager>
 
-#include <QTemporaryFile>
-
 #include <QFile>
 #include <QDir>
 #include <QStandardPaths>
@@ -108,7 +106,7 @@ KZip *AbstractImportExportJob::archive() const
 void AbstractImportExportJob::backupUiRcFile(const QString &configFileName, const QString &application)
 {
     const QString configrcStr(configFileName);
-    const QString configrc = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kxmlgui5/") + application + QLatin1Char('/') + configrcStr;
+    const QString configrc = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kxmlgui5/") + application + QLatin1Char('/') + configrcStr;
     if (QFileInfo::exists(configrc)) {
         backupFile(configrc, Utils::configsPath(), configrcStr);
     }
@@ -153,13 +151,13 @@ void AbstractImportExportJob::overwriteDirectory(const QString &path, const KArc
         if (overwriteDirectoryMessageBox(path)) {
             const KArchiveDirectory *dirEntry = static_cast<const KArchiveDirectory *>(entry);
             if (!dirEntry->copyTo(path)) {
-                qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "directory cannot overwrite to " << path;
+                qCDebug(PIMDATAEXPORTERCORE_LOG) << "directory cannot overwrite to " << path;
             }
         }
     } else {
         const KArchiveDirectory *dirEntry = static_cast<const KArchiveDirectory *>(entry);
         if (dirEntry->copyTo(path)) {
-            qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "directory cannot overwrite to " << path;
+            qCDebug(PIMDATAEXPORTERCORE_LOG) << "directory cannot overwrite to " << path;
         }
     }
 }
@@ -204,7 +202,7 @@ void AbstractImportExportJob::storeArchiveInfoResources(const KArchiveDirectory
                 files.debug();
                 mListResourceFile.append(files);
             } else {
-                qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " Problem in archive. number of file " << lst.count();
+                qCDebug(PIMDATAEXPORTERCORE_LOG) << " Problem in archive. number of file " << lst.count();
             }
         }
     }
@@ -288,7 +286,7 @@ Akonadi::Collection::Id AbstractImportExportJob::convertPathToId(const QString &
 void AbstractImportExportJob::initializeImportJob()
 {
     if (mTempDir) {
-        qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " initializeImportJob already called";
+        qCDebug(PIMDATAEXPORTERCORE_LOG) << " initializeImportJob already called";
     } else {
         mTempDir = new QTemporaryDir();
         mTempDirName = mTempDir->path();
@@ -302,7 +300,7 @@ void AbstractImportExportJob::copyToDirectory(const KArchiveEntry *entry, const
 {
     const KArchiveDirectory *subfolderDir = static_cast<const KArchiveDirectory *>(entry);
     if (!subfolderDir->copyTo(dest)) {
-        qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "directory cannot copy to " << dest;
+        qCDebug(PIMDATAEXPORTERCORE_LOG) << "directory cannot copy to " << dest;
     }
     Q_EMIT info(i18n("\"%1\" was copied.", dest));
 }
@@ -313,18 +311,18 @@ void AbstractImportExportJob::copyToFile(const KArchiveFile *archivefile, const
     const QString copyToDirName(mTempDirName + QLatin1Char('/') + prefix);
     const bool created = dir.mkpath(copyToDirName);
     if (!created) {
-        qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " directory :" << prefix << " not created";
+        qCDebug(PIMDATAEXPORTERCORE_LOG) << " directory :" << prefix << " not created";
     }
 
     if (!archivefile->copyTo(copyToDirName)) {
-        qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "file " << filename << " can not copy to " << dest;
+        qCDebug(PIMDATAEXPORTERCORE_LOG) << "file " << filename << " can not copy to " << dest;
     }
     QFile file;
     file.setFileName(copyToDirName + QLatin1Char('/') + filename);
 
     //QFile doesn't overwrite => remove old file before
-    //qCDebug(PIMSETTINGEXPORTERCORE_LOG)<<" dest "<<dest;
-    //qCDebug(PIMSETTINGEXPORTERCORE_LOG)<<" file "<<file.fileName();
+    //qCDebug(PIMDATAEXPORTERCORE_LOG)<<" dest "<<dest;
+    //qCDebug(PIMDATAEXPORTERCORE_LOG)<<" file "<<file.fileName();
     QFile destination(dest);
     if (destination.exists()) {
         destination.remove();
@@ -389,12 +387,14 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
                 const KArchiveEntry *fileResouceEntry = mArchiveDirectory->entry(value.akonadiConfigFile);
                 if (fileResouceEntry && fileResouceEntry->isFile()) {
                     const KArchiveFile *file = static_cast<const KArchiveFile *>(fileResouceEntry);
-                    file->copyTo(copyToDirName);
+                    if (!file->copyTo(copyToDirName)) {
+                        qCDebug(PIMDATAEXPORTERCORE_LOG) << "file " << value.akonadiConfigFile << " can not copy to " << copyToDirName;
+                    }
                     QString resourceName(file->name());
 
                     QString filename(file->name());
                     //TODO adapt filename otherwise it will use all the time the same filename.
-                    qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " filename :" << filename;
+                    qCDebug(PIMDATAEXPORTERCORE_LOG) << " filename :" << filename;
 
                     KSharedConfig::Ptr resourceConfig = KSharedConfig::openConfig(copyToDirName + QLatin1Char('/') + resourceName);
 
@@ -408,7 +408,9 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
                     const KArchiveEntry *dataResouceEntry = mArchiveDirectory->entry(dataFile);
                     if (dataResouceEntry->isFile()) {
                         const KArchiveFile *file = static_cast<const KArchiveFile *>(dataResouceEntry);
-                        file->copyTo(newUrl);
+                        if (!file->copyTo(newUrl)) {
+                            qCDebug(PIMDATAEXPORTERCORE_LOG) << "file " << dataFile << " can not copy to " << newUrl;
+                        }
                     }
                     settings.insert(QStringLiteral("Path"), newUrl);
 
@@ -429,7 +431,7 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
                     const QString newResource = mCreateResource->createResource(resourceBaseName, filename, settings);
                     infoAboutNewResource(newResource);
                     resourceToSync << newResource;
-                    qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " newResource" << newResource;
+                    qCDebug(PIMDATAEXPORTERCORE_LOG) << " newResource" << newResource;
                 }
             }
         }
@@ -440,14 +442,25 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
     return resourceToSync;
 }
 
-void AbstractImportExportJob::addSpecificResourceSettings(KSharedConfig::Ptr /*resourceConfig*/, const QString & /*resourceName*/, QMap<QString, QVariant> & /*settings*/)
+void AbstractImportExportJob::addSpecificResourceSettings(const KSharedConfig::Ptr /*resourceConfig*/ &, const QString & /*resourceName*/, QMap<QString, QVariant> & /*settings*/)
 {
     //Redefine it in subclass
 }
 
+bool AbstractImportExportJob::copyArchiveFileTo(const KArchiveFile *file, const QString &destination)
+{
+    const bool result = file->copyTo(destination);
+    if (!result) {
+        qCDebug(PIMDATAEXPORTERCORE_LOG) << "file " << file->name() << " can not copy to " << destination;
+    }
+    return result;
+}
+
 void AbstractImportExportJob::extractZipFile(const KArchiveFile *file, const QString &source, const QString &destination, bool isStoredAsZippedArchive)
 {
-    file->copyTo(source);
+    if (!file->copyTo(source)) {
+        qCDebug(PIMDATAEXPORTERCORE_LOG) << "file " << file->name() << " can not copy to " << source;
+    }
     QDir dest(destination);
     if (!dest.exists()) {
         dest.mkpath(destination);
@@ -488,7 +501,7 @@ void AbstractImportExportJob::restoreUiRcFile(const QString &configNameStr, cons
     const KArchiveEntry *configNameentry = mArchiveDirectory->entry(Utils::configsPath() + configNameStr);
     if (configNameentry && configNameentry->isFile()) {
         const KArchiveFile *configNameconfiguration = static_cast<const KArchiveFile *>(configNameentry);
-        const QString configNamerc = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kxmlgui5/") + applicationName + QLatin1Char('/') + configNameStr;
+        const QString configNamerc = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kxmlgui5/") + applicationName + QLatin1Char('/') + configNameStr;
         if (QFileInfo::exists(configNamerc)) {
             if (overwriteConfigMessageBox(configNameStr)) {
                 copyToFile(configNameconfiguration, configNamerc, configNameStr, Utils::configsPath());
@@ -627,7 +640,14 @@ void AbstractImportExportJob::convertCollectionStrToAkonadiId(const KSharedConfi
 {
     if (config->hasGroup(groupName)) {
         KConfigGroup eventGroup = config->group(groupName);
-        const QString eventLastEventSelectedFolder(key);
-        convertRealPathToCollection(eventGroup, eventLastEventSelectedFolder, false);
+        convertRealPathToCollection(eventGroup, key, false);
+    }
+}
+
+void AbstractImportExportJob::convertCollectionListStrToAkonadiId(const KSharedConfig::Ptr &config, const QString &groupName, const QString &key, bool addCollectionPrefix)
+{
+    if (config->hasGroup(groupName)) {
+        KConfigGroup group = config->group(groupName);
+        convertRealPathToCollectionList(group, key, addCollectionPrefix);
     }
 }
